@@ -30,7 +30,6 @@
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/registry.h>
 #include <KWayland/Client/surface.h>
-#include <KWayland/Client/shell.h>
 
 FullScreenOverlay::FullScreenOverlay(QQuickWindow *parent)
     : QQuickWindow(parent)
@@ -39,6 +38,7 @@ FullScreenOverlay::FullScreenOverlay(QQuickWindow *parent)
     setWindowState(Qt::WindowFullScreen);
    // connect(this, &FullScreenOverlay::activeFocusItemChanged, this, [this]() {qWarning()<<"hide()";});
     initWayland();
+    setWindowStates(Qt::WindowFullScreen);
 }
 
 FullScreenOverlay::~FullScreenOverlay()
@@ -71,23 +71,12 @@ void FullScreenOverlay::initWayland()
             m_plasmaShellSurface->setSkipTaskbar(true);
         }
     );
-    /*
-    connect(registry, &Registry::shellAnnounced, this,
-        [this, registry] (quint32 name, quint32 version) {
 
-            m_shellInterface = registry->createShell(name, version, this);
-            if (!m_shellInterface) {
-                return;
-            }
-            //bshah: following code results in error...
-            //wl_surface@67: error 0: ShellSurface already created
-            //Wayland display got fatal error 71: Protocol error
-            //Additionally, errno was set to 71: Protocol error
-            m_shellSurface = m_shellInterface->createSurface(m_surface, this);
-        }
-    );*/
     registry->setup();
     connection->roundtrip();
+    //HACK: why the first time is shown fullscreen won't work?
+    showFullScreen();
+    hide();
 }
 
 bool FullScreenOverlay::event(QEvent *e)
@@ -98,7 +87,12 @@ bool FullScreenOverlay::event(QEvent *e)
         QPlatformSurfaceEvent *pe = static_cast<QPlatformSurfaceEvent*>(e);
 
         if (pe->surfaceEventType() == QPlatformSurfaceEvent::SurfaceCreated) {
-            KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager | NET::FullScreen);
+            //KWindowSystem::setState(winId(), NET::SkipTaskbar | NET::SkipPager | NET::FullScreen);
+           // setWindowStates(Qt::WindowFullScreen);
+            if (m_plasmaShellSurface) {
+                m_plasmaShellSurface->setSkipTaskbar(true);
+            }
+
             if (!m_acceptsFocus) {
                 setFlags(flags() | Qt::FramelessWindowHint|Qt::WindowDoesNotAcceptFocus);
                 //KWindowSystem::setType(winId(), NET::Dock);
@@ -106,6 +100,10 @@ bool FullScreenOverlay::event(QEvent *e)
                 setFlags(flags() | Qt::FramelessWindowHint);
             }
         }
+    } else if (e->type() == QEvent::Show) {
+        if (m_plasmaShellSurface) {
+            m_plasmaShellSurface->setSkipTaskbar(true);
+        }
     }
 
     return QQuickWindow::event(e);
